% Costanti fisiche
global g = 9.81;
% Dati sul carico a monte
global h1 = 2;
% Dati sul carico a valle
global h2 = 0.5;
% Dati sul fluido
global rho = 1e3;
global mu = 1e-3;
% Dati sulla condotta
global es = 0.001;
global D1 = 0.04;
global L1 = 2;
global k1a = 0.5;
global D2 = 0.02;
global L2 = 2;


function z = target_function(Q)
	global g;
	% Dati sul carico a monte
	global h1;
	% Dati sul carico a valle
	global h2;
	% Dati sul fluido
	global rho;
	global mu;
	% Dati sulla condotta
	global es;
	global D1;
	global L1;
	global k1a;
	global D2;
	global L2;

	% Calcolo il carico totale
	H12 = h1 - h2;
	% Calcolo la viscosità cinematica
	nu = mu ./ rho;

	% PRIMA TRATTA
	% Calcolo la velocità
	v1 = hspeed(Q, D1);
	% Calcolo il numero di Reynolds
	Re1 = Reynolds(v1, D1, nu);
	% Calcolo il coefficiente di attrito
	f1 = churchill(Re1, es ./ D1);
	% Calcolo le perdite di carico distribuite
	dloss1 = loss_l(f1, D1, L1, v1, g);
	% Calcolo le perdite di carico concentrate
	dlossK1 = loss_k(k1a, v1, g);

	% SECONDA TRATTA
	% Calcolo la velocità
	v2 = hspeed(Q, D2);
	% Calcolo il numero di Reynolds
	Re2 = Reynolds(v2, D2, nu);
	% Calcolo il coefficiente di attrito
	f2 = churchill(Re2, es ./ D2);
	% Calcolo le perdite di carico distribuite
	dloss2 = loss_l(f2, D2, L2, v2, g);

	% Calcolo il valore della funzione
	z = H12 - dloss1 - dlossK1 - dloss2;
end

% target_function(0.002)

% Traccio la funzione
x = linspace(0, 0.001, 200);
plot(x, target_function(x));
grid()

% Soluzione usando il metodo di Octave
[X, FVAL, INFO] = fsolve(@target_function, 0.001);
X, FVAL, INFO

% Calcolo la portata in L/s
Q = 1000 .* X
v1 = hspeed(X, D1)
v2 = hspeed(X, D2)
